@@ -1,4 +1,4 @@
-# $Id: /mirror/coderepos/lang/perl/Data-Valve/trunk/lib/Data/Valve/BucketStore.pm 65685 2008-07-14T21:35:24.074501Z daisuke  $
+# $Id: /mirror/coderepos/lang/perl/Data-Valve/trunk/lib/Data/Valve/BucketStore.pm 66548 2008-07-22T00:38:42.978696Z daisuke  $
 
 package Data::Valve::BucketStore;
 use Moose::Role;
@@ -8,7 +8,7 @@ requires 'try_push';
 has 'context' => (
     is       => 'rw',
     isa      => 'Data::Valve',
-    handles  => [ qw(max_items interval) ],
+    handles  => [ qw(max_items interval strict_interval) ],
 );
 
 no Moose;
