@@ -1,4 +1,4 @@
-# $Id: /mirror/coderepos/lang/perl/Data-Valve/trunk/lib/Data/Valve/BucketStore/Memory.pm 65685 2008-07-14T21:35:24.074501Z daisuke  $
+# $Id: /mirror/coderepos/lang/perl/Data-Valve/trunk/lib/Data/Valve/BucketStore/Memory.pm 66548 2008-07-22T00:38:42.978696Z daisuke  $
 
 package Data::Valve::BucketStore::Memory;
 use Moose;
@@ -8,25 +8,21 @@ with 'Data::Valve::BucketStore';
 has 'store' => (
     is => 'rw',
     isa => 'HashRef',
+    required => 1,
+    default => sub { +{} }
 );
 
 __PACKAGE__->meta->make_immutable;
 
 no Moose;
 
-sub BUILD { 
-    my $self = shift;
-    $self->store( {
-        __default => $self->create_bucket()
-    } );
-}
-
 sub create_bucket
 {
     my $self = shift;
     return Data::Valve::Bucket->new(
         max_items => $self->max_items,
-        interval  => $self->interval
+        interval  => $self->interval,
+        strict_interval => $self->strict_interval,
     );
 }
 
